Index: /trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/Functions.java
===================================================================
--- /trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/Functions.java	(revision 15316)
+++ /trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/Functions.java	(revision 15317)
@@ -391,11 +391,11 @@
      * Get keys that follow a regex
      * @param env the environment
      * @param key_regex the pattern that the key must match
      * @return the values for the keys that match the pattern
      * @see Functions#tag_regex(Environment, String, String)
      * @since 15315
      */
-    public static List<String> tag_regex(final Environment env, String key_regex) { // NO_UCD (unused code)
-        return tag_regex(env, key_regex, "");
+    public static List<String> tag_regex(final Environment env, String keyRegex) { // NO_UCD (unused code)
+        return tag_regex(env, keyRegex, "");
     }
 
@@ -403,7 +403,7 @@
      * Get keys that follow a regex
      * @param env the environment
-     * @param key_regex the pattern that the key must match
+     * @param keyRegex the pattern that the key must match
+     * @param flags a string that may contain "i" (case insensitive), "m" (multiline) and "s" ("dot all")
      * @return the values for the keys that match the pattern
-     * @param flags a string that may contain "i" (case insensitive), "m" (multiline) and "s" ("dot all")
      * @see Pattern#CASE_INSENSITIVE
      * @see Pattern#DOTALL
@@ -411,7 +411,7 @@
      * @since 15315
      */
-    public static List<String> tag_regex(final Environment env, String key_regex, String flags) { // NO_UCD (unused code)
+    public static List<String> tag_regex(final Environment env, String keyRegex, String flags) { // NO_UCD (unused code)
         int f = parse_regex_flags(flags);
-        Pattern compiled = Pattern.compile(key_regex, f);
+        Pattern compiled = Pattern.compile(keyRegex, f);
         return env.osm.getKeys().entrySet().stream()
                 .filter(object -> compiled.matcher(object.getKey()).find())
@@ -422,10 +422,10 @@
      * Parse flags for regex usage. Shouldn't be used in mapcss
      * @param flags a string that may contain "i" (case insensitive), "m" (multiline) and "s" ("dot all")
+     * @return An int that can be used by a {@link Pattern} object
      * @see Pattern#CASE_INSENSITIVE
      * @see Pattern#DOTALL
      * @see Pattern#MULTILINE
-     * @return An int that can be used by a {@link Pattern} object
-     */
-    private static final int parse_regex_flags(String flags) {
+     */
+    private static int parse_regex_flags(String flags) {
         int f = 0;
         if (flags.contains("i")) {
@@ -391,11 +391,11 @@
      * Get keys that follow a regex
      * @param env the environment
-     * @param key_regex the pattern that the key must match
+     * @param keyRegex the pattern that the key must match
      * @return the values for the keys that match the pattern
      * @see Functions#tag_regex(Environment, String, String)
